==> flutter_tapresearch-0.0.1.tar.gz: lib/flutter_tapresearch.dart <==
import 'dart:async';
import 'package:flutter/services.dart';

typedef void TapResearchSurveyWallOpenedListener();
typedef void TapResearchSurveyWallDismissedListener();
typedef void TapResearchDidReceiveRewardListener(int reward);
typedef void TapResearchIsSurveyWallAvailableListener(int surveyAvailable);

class TapResearch {
  static TapResearch get instance => _instance;

  final MethodChannel _channel;

  static final TapResearch _instance = TapResearch.private(
    const MethodChannel('tapr'),
  );

  TapResearch.private(MethodChannel channel) : _channel = channel {
    _channel.setMethodCallHandler(_platformCallHandler);
  }

  static TapResearchSurveyWallOpenedListener
      _tapResearchSurveyWallOpenedListener;
  static TapResearchSurveyWallDismissedListener
      _tapResearchSurveyWallDismissedListener;
  static TapResearchDidReceiveRewardListener
      _tapResearchDidReceiveRewardListener;
  static TapResearchIsSurveyWallAvailableListener
      _tapResearchIsSurveyWallAvailableListener;

  Future<void> init({String apiToken, String userId}) async {
    assert(apiToken != null && apiToken.isNotEmpty);

    return _channel.invokeMethod("init", <String, dynamic>{
      'api_token': apiToken,
      'user_id': userId,
    });
  }

  Future<void> initPlacement({String placementId}) async {
    return _channel.invokeMethod("initPlacement", <String, dynamic>{
      'placement_id': placementId,
    });
  }

  Future<void> showSurveyWall() async {
    try {
      await _channel.invokeMethod('showSurveyWall');
    } catch (e) {
      print(e.toString());
    }
  }

  Future<void> setNavigationBarText(String navBarText) async {
    try {
      await _channel.invokeMethod('setNavigationBarText', navBarText);
    } catch (e) {
      print(e.toString());
    }
  }

  Future<void> setNavigationBarColor(String hexColor) async {
    try {
      await _channel.invokeMethod('setNavigationBarColor', hexColor);
    } catch (e) {
      print(e.toString());
    }
  }

  Future<void> setNavigationBarTextColor(String hexColor) async {
    try {
      await _channel.invokeMethod('setNavigationBarTextColor', hexColor);
    } catch (e) {
      print(e.toString());
    }
  }

  Future _platformCallHandler(MethodCall call) async {
    print(
        "TapResearch _platformCallHandler call ${call.method} ${call.arguments}");

    switch (call.method) {
      case "tapResearchSurveyWallOpened":
        _tapResearchSurveyWallOpenedListener();

        break;

      case "tapResearchSurveyWallDismissed":
        _tapResearchSurveyWallDismissedListener();

        break;

      case "tapResearchDidReceiveReward":
        _tapResearchDidReceiveRewardListener(call.arguments);

        break;

      case "isSurveyWallAvailable":
        _tapResearchIsSurveyWallAvailableListener(call.arguments);

        break;

      default:
        print('Unknown method ${call.method} ');
    }
  }

  void setTapResearchSurveyWallOpenedListener(
          TapResearchSurveyWallOpenedListener
              tapResearchSurveyWallOpenedListener) =>
      _tapResearchSurveyWallOpenedListener =
          tapResearchSurveyWallOpenedListener;

  void setTapResearchSurveyWallDismissedListener(
          TapResearchSurveyWallDismissedListener
              tapResearchSurveyWallDismissedListener) =>
      _tapResearchSurveyWallDismissedListener =
          tapResearchSurveyWallDismissedListener;

  void setTapResearchDidReceiveRewardListener(
          TapResearchDidReceiveRewardListener
              tapResearchDidReceiveRewardListener) =>
      _tapResearchDidReceiveRewardListener =
          tapResearchDidReceiveRewardListener;

  void setTapResearchIsSurveyWallAvailableListener(
          TapResearchIsSurveyWallAvailableListener
              tapResearchIsSurveyWallAvailableListener) =>
      _tapResearchIsSurveyWallAvailableListener =
          tapResearchIsSurveyWallAvailableListener;
}

==> flutter_tapresearch-0.0.2.tar.gz: lib/flutter_tapresearch.dart <==
import 'dart:async';
import 'package:flutter/services.dart';

typedef void TapResearchSurveyWallOpenedListener();
typedef void TapResearchSurveyWallDismissedListener();
typedef void TapResearchDidReceiveRewardListener(int reward);
typedef void TapResearchIsSurveyWallAvailableListener(int surveyAvailable);

class TapResearch {
  static TapResearch get instance => _instance;

  final MethodChannel _channel;

  static final TapResearch _instance = TapResearch.private(
    const MethodChannel('ios_native'),
  );

  TapResearch.private(MethodChannel channel) : _channel = channel {
    _channel.setMethodCallHandler(_platformCallHandler);
  }

  static TapResearchSurveyWallOpenedListener
      _tapResearchSurveyWallOpenedListener;
  static TapResearchSurveyWallDismissedListener
      _tapResearchSurveyWallDismissedListener;
  static TapResearchDidReceiveRewardListener
      _tapResearchDidReceiveRewardListener;
  static TapResearchIsSurveyWallAvailableListener
      _tapResearchIsSurveyWallAvailableListener;

  Future<void> init({String apiToken, String userId}) async {
    assert(apiToken != null && apiToken.isNotEmpty);

    return _channel.invokeMethod("init", <String, dynamic>{
      'api_token': apiToken,
      'user_id': userId,
    });
  }

  Future<void> initPlacement({String placementId}) async {
    return _channel.invokeMethod("initPlacement", <String, dynamic>{
      'placement_id': placementId,
    });
  }

  Future<void> showSurveyWall() async {
    try {
      await _channel.invokeMethod('showSurveyWall');
    } catch (e) {
      print(e.toString());
    }
  }

  Future<void> setNavigationBarText(String navBarText) async {
    try {
      await _channel.invokeMethod('setNavigationBarText', navBarText);
    } catch (e) {
      print(e.toString());
    }
  }

  Future<void> setNavigationBarColor(String hexColor) async {
    try {
      await _channel.invokeMethod('setNavigationBarColor', hexColor);
    } catch (e) {
      print(e.toString());
    }
  }

  Future<void> setNavigationBarTextColor(String hexColor) async {
    try {
      await _channel.invokeMethod('setNavigationBarTextColor', hexColor);
    } catch (e) {
      print(e.toString());
    }
  }

  Future _platformCallHandler(MethodCall call) async {
    print(
        "TapResearch _platformCallHandler call ${call.method} ${call.arguments}");

    switch (call.method) {
      case "tapResearchSurveyWallOpened":
        _tapResearchSurveyWallOpenedListener();

        break;

      case "tapResearchSurveyWallDismissed":
        _tapResearchSurveyWallDismissedListener();

        break;

      case "tapResearchDidReceiveReward":
        _tapResearchDidReceiveRewardListener(call.arguments);

        break;

      case "isSurveyWallAvailable":
        _tapResearchIsSurveyWallAvailableListener(call.arguments);

        break;

      default:
        print('Unknown method ${call.method} ');
    }
  }

  void setTapResearchSurveyWallOpenedListener(
          TapResearchSurveyWallOpenedListener
              tapResearchSurveyWallOpenedListener) =>
      _tapResearchSurveyWallOpenedListener =
          tapResearchSurveyWallOpenedListener;

  void setTapResearchSurveyWallDismissedListener(
          TapResearchSurveyWallDismissedListener
              tapResearchSurveyWallDismissedListener) =>
      _tapResearchSurveyWallDismissedListener =
          tapResearchSurveyWallDismissedListener;

  void setTapResearchDidReceiveRewardListener(
          TapResearchDidReceiveRewardListener
              tapResearchDidReceiveRewardListener) =>
      _tapResearchDidReceiveRewardListener =
          tapResearchDidReceiveRewardListener;

  void setTapResearchIsSurveyWallAvailableListener(
          TapResearchIsSurveyWallAvailableListener
              tapResearchIsSurveyWallAvailableListener) =>
      _tapResearchIsSurveyWallAvailableListener =
          tapResearchIsSurveyWallAvailableListener;
}
